@@ -3,13 +3,14 @@ from typing import Optional
 import warnings
 
 import numpy as np
-import pandas as pd
+
+# import pandas as pd
+import lazy_loader as lazy
 from Bio import SeqIO
 from Bio.Align import MultipleSeqAlignment
 from Bio.Data.IUPACData import extended_protein_values
 from PIL import Image
-from weblogo import LogoData, LogoFormat, LogoOptions, formatters
-from weblogo.seq import Alphabet
+
 
 from .alignment_utils import align
 from .alphabets import (
@@ -27,6 +28,8 @@ from .draw_utils import draw_alignment, view_alignment, aa_chemistry_simple, nt_
 from .encoders import onehot_encoder_from_alphabet
 from .SeqLike import SeqLike
 
+pd = lazy.load("pandas")
+
 
 @pd.api.extensions.register_series_accessor("seq")
 class SeqLikeAccessor:
@@ -149,6 +152,7 @@ class SeqLikeAccessor:
         :param **kwargs: additional weblogo arguments
         :returns: PIL Image object
         """
+        import weblogo as wl
 
         def highlight_consensus(labels, consensus, ref):
             new_labels = list()
@@ -172,10 +176,10 @@ class SeqLikeAccessor:
             seqnum_labels = range(1, len(consensus) + 1)
 
         # set weblogo options
-        opts = LogoOptions(
-            formatter=formatters[logo_format],
+        opts = wl.LogoOptions(
+            formatter=wl.formatters[logo_format],
             stacks_per_line=cols,
-            color_scheme=color_scheme,
+            color_scheme=color_scheme(),
             logo_font=logo_font,
             resolution=resolution,
             **kwargs,
@@ -185,14 +189,14 @@ class SeqLikeAccessor:
 
         # remove gap and stop characters so that they are not included in weblogo
         ignore = [gap_letter, stop_letter]
-        alphabet = Alphabet([s for s in self.alphabet if s not in ignore])
+        alphabet = wl.seq.Alphabet([s for s in self.alphabet if s not in ignore])
         counts = [count for s, count in self.as_counts_by_alphabet() if s not in ignore]
 
         # count position-specific frequencies
-        data = LogoData.from_counts(alphabet, np.array(counts).T)
+        data = wl.LogoData.from_counts(alphabet, np.array(counts).T)
 
         # return logo as png image
-        logo = opts.formatter(data, LogoFormat(data, opts))
+        logo = opts.formatter(data, wl.LogoFormat(data, opts))
         return Image.open(io.BytesIO(logo))
 
     def align(self, preserve_order: bool = True, *args, **kwargs):
